@@ -1,5 +1,19 @@
 var NAVTREEINDEX157 =
 {
+"df/d96/structisc_1_1dhcp_1_1Dhcp6Parser_1_1symbol__type.html#abbd51e980b09e242c39305f9dcd88e16":[3,0,1,13,73,4,3],
+"df/d96/structisc_1_1dhcp_1_1Dhcp6Parser_1_1symbol__type.html#abbd51e980b09e242c39305f9dcd88e16":[4,0,0,11,73,4,3],
+"df/d96/structisc_1_1dhcp_1_1Dhcp6Parser_1_1symbol__type.html#ac2ca6f0c7ed8a70b609d152397b990b6":[3,0,1,13,73,4,2],
+"df/d96/structisc_1_1dhcp_1_1Dhcp6Parser_1_1symbol__type.html#ac2ca6f0c7ed8a70b609d152397b990b6":[4,0,0,11,73,4,2],
+"df/d96/structisc_1_1dhcp_1_1Dhcp6Parser_1_1symbol__type.html#ade9bb51a6a07bcd3636464531858fe61":[3,0,1,13,73,4,5],
+"df/d96/structisc_1_1dhcp_1_1Dhcp6Parser_1_1symbol__type.html#ade9bb51a6a07bcd3636464531858fe61":[4,0,0,11,73,4,5],
+"df/d9d/namespaceisc_1_1asiodns.html":[3,0,1,1],
+"df/d9d/namespaceisc_1_1asiodns.html#a07df9701d4f93e990c2dc734b98684ef":[3,0,1,1,13],
+"df/d9d/namespaceisc_1_1asiodns.html#a322c71d77902d2db025c902907beb62e":[3,0,1,1,14],
+"df/d9d/namespaceisc_1_1asiodns.html#a4539eb12f2049b66ae862d36cb7f62d0":[3,0,1,1,7],
+"df/d9d/namespaceisc_1_1asiodns.html#a5c5d1906692386ccdb561f71a4816cc3":[3,0,1,1,9],
+"df/d9d/namespaceisc_1_1asiodns.html#a714bdba9f4965a320fb0a7449b544b69":[3,0,1,1,4],
+"df/d9d/namespaceisc_1_1asiodns.html#a75b064732b70d5f4e453f399d386dae0":[3,0,1,1,5],
+"df/d9d/namespaceisc_1_1asiodns.html#a7b5f3093d3eb69f9690bc6a6eadfc771":[3,0,1,1,10],
 "df/d9d/namespaceisc_1_1asiodns.html#a83c0bbe734707167b56161f1451856c1":[3,0,1,1,3],
 "df/d9d/namespaceisc_1_1asiodns.html#a8b2073aae8ab4ff554aec3c65ba3ff51":[3,0,1,1,11],
 "df/d9d/namespaceisc_1_1asiodns.html#a98bcfb561a1c9a47a270fb7fb3f97eb5":[3,0,1,1,6],
@@ -10,14 +24,14 @@ var NAVTREEINDEX157 =
 "df/da1/crypto__hash_8cc_source.html":[5,0,0,2,5,4],
 "df/da2/command__creator_8h.html":[5,0,0,1,1,6,1],
 "df/da2/command__creator_8h_source.html":[5,0,0,1,1,6,1],
-"df/da3/classisc_1_1dhcp_1_1Token.html":[3,0,1,13,334],
-"df/da3/classisc_1_1dhcp_1_1Token.html":[4,0,0,11,334],
-"df/da3/classisc_1_1dhcp_1_1Token.html#a46101683b849d004f88c2ab9eef6e634":[3,0,1,13,334,2],
-"df/da3/classisc_1_1dhcp_1_1Token.html#a46101683b849d004f88c2ab9eef6e634":[4,0,0,11,334,2],
-"df/da3/classisc_1_1dhcp_1_1Token.html#a687ff487646e85a5f4ea72c0727587ef":[3,0,1,13,334,0],
-"df/da3/classisc_1_1dhcp_1_1Token.html#a687ff487646e85a5f4ea72c0727587ef":[4,0,0,11,334,0],
-"df/da3/classisc_1_1dhcp_1_1Token.html#ac25e6c10aa79a9f17fe40584cdcb7428":[3,0,1,13,334,1],
-"df/da3/classisc_1_1dhcp_1_1Token.html#ac25e6c10aa79a9f17fe40584cdcb7428":[4,0,0,11,334,1],
+"df/da3/classisc_1_1dhcp_1_1Token.html":[3,0,1,13,335],
+"df/da3/classisc_1_1dhcp_1_1Token.html":[4,0,0,11,335],
+"df/da3/classisc_1_1dhcp_1_1Token.html#a46101683b849d004f88c2ab9eef6e634":[3,0,1,13,335,2],
+"df/da3/classisc_1_1dhcp_1_1Token.html#a46101683b849d004f88c2ab9eef6e634":[4,0,0,11,335,2],
+"df/da3/classisc_1_1dhcp_1_1Token.html#a687ff487646e85a5f4ea72c0727587ef":[3,0,1,13,335,0],
+"df/da3/classisc_1_1dhcp_1_1Token.html#a687ff487646e85a5f4ea72c0727587ef":[4,0,0,11,335,0],
+"df/da3/classisc_1_1dhcp_1_1Token.html#ac25e6c10aa79a9f17fe40584cdcb7428":[3,0,1,13,335,1],
+"df/da3/classisc_1_1dhcp_1_1Token.html#ac25e6c10aa79a9f17fe40584cdcb7428":[4,0,0,11,335,1],
 "df/da3/classisc_1_1subnet__cmds_1_1ConfigDiffManager.html":[3,0,1,40,0],
 "df/da3/classisc_1_1subnet__cmds_1_1ConfigDiffManager.html":[4,0,0,37,0],
 "df/da3/classisc_1_1subnet__cmds_1_1ConfigDiffManager.html#a3a6055df72e83d15a50345b8e1db0e33":[3,0,1,40,0,2],
@@ -66,8 +80,8 @@ var NAVTREEINDEX157 =
 "df/db2/classisc_1_1radius_1_1CfgAttributes_1_1AttributeValue.html#aad28e564e7918f46a0833e66bb15f91b":[4,0,0,33,9,0,3],
 "df/db2/classisc_1_1radius_1_1CfgAttributes_1_1AttributeValue.html#ad67f84ee30cc12ec833916705df2d586":[3,0,1,36,9,0,0],
 "df/db2/classisc_1_1radius_1_1CfgAttributes_1_1AttributeValue.html#ad67f84ee30cc12ec833916705df2d586":[4,0,0,33,9,0,0],
-"df/db3/structisc_1_1dhcp_1_1SubnetIdPoolIdIndexTag.html":[3,0,1,13,320],
-"df/db3/structisc_1_1dhcp_1_1SubnetIdPoolIdIndexTag.html":[4,0,0,11,320],
+"df/db3/structisc_1_1dhcp_1_1SubnetIdPoolIdIndexTag.html":[3,0,1,13,321],
+"df/db3/structisc_1_1dhcp_1_1SubnetIdPoolIdIndexTag.html":[4,0,0,11,321],
 "df/db6/classisc_1_1http_1_1HttpResponseError.html":[3,0,1,24,34],
 "df/db6/classisc_1_1http_1_1HttpResponseError.html":[4,0,0,21,34],
 "df/db6/classisc_1_1http_1_1HttpResponseError.html#acb093940a312ee4c0f387b97d0b78663":[3,0,1,24,34,0],
@@ -154,8 +168,8 @@ var NAVTREEINDEX157 =
 "df/dbd/namespaceisc_1_1util_1_1str.html#aaec82d24ee9b70456efd98c2b864fc83":[3,0,1,43,4,5],
 "df/dbd/namespaceisc_1_1util_1_1str.html#aef8b40be08e0afc14e5966bc31ef758b":[3,0,1,43,4,18],
 "df/dbd/namespaceisc_1_1util_1_1str.html#af6bf5680c940857827073018c6415d7a":[3,0,1,43,4,19],
-"df/dbf/classisc_1_1dhcp_1_1SimpleParser6.html":[3,0,1,13,301],
-"df/dbf/classisc_1_1dhcp_1_1SimpleParser6.html":[4,0,0,11,301],
+"df/dbf/classisc_1_1dhcp_1_1SimpleParser6.html":[3,0,1,13,302],
+"df/dbf/classisc_1_1dhcp_1_1SimpleParser6.html":[4,0,0,11,302],
 "df/dbf/csv__lease__file6_8h.html":[5,0,0,2,10,72],
 "df/dbf/csv__lease__file6_8h_source.html":[5,0,0,2,10,72],
 "df/dc0/option__int_8h.html":[5,0,0,2,8,55],
@@ -235,19 +249,5 @@ var NAVTREEINDEX157 =
 "df/dc7/classisc_1_1dhcp_1_1CfgDUID.html#ae34635ded1c2f7c557b21ebb52d20947":[3,0,1,13,19,14],
 "df/dc7/classisc_1_1dhcp_1_1CfgDUID.html#ae34635ded1c2f7c557b21ebb52d20947":[4,0,0,11,19,14],
 "df/dc9/classisc_1_1dns_1_1DNSMessageFORMERR.html":[3,0,1,15,10],
-"df/dc9/classisc_1_1dns_1_1DNSMessageFORMERR.html":[4,0,0,13,9],
-"df/dc9/classisc_1_1dns_1_1DNSMessageFORMERR.html#acc38fd1bc37ab3af333eb0dda4f597d0":[3,0,1,15,10,1],
-"df/dc9/classisc_1_1dns_1_1DNSMessageFORMERR.html#acc38fd1bc37ab3af333eb0dda4f597d0":[4,0,0,13,9,1],
-"df/dc9/classisc_1_1dns_1_1DNSMessageFORMERR.html#ad6a91d8211d30400c4025817c36bdc69":[3,0,1,15,10,0],
-"df/dc9/classisc_1_1dns_1_1DNSMessageFORMERR.html#ad6a91d8211d30400c4025817c36bdc69":[4,0,0,13,9,0],
-"df/dcc/classDUID.html":[4,0,5],
-"df/dcc/classDUID.html#a0edfef53b87748e0f5dcd9801666e213":[4,0,5,2],
-"df/dcc/classDUID.html#adbe04141f4d8013a01effadda9c97c50":[4,0,5,0],
-"df/dcc/classDUID.html#adbe04141f4d8013a01effadda9c97c50a16c50595a1a2eb96e71c460107b43366":[4,0,5,0,3],
-"df/dcc/classDUID.html#adbe04141f4d8013a01effadda9c97c50a336b8a356e2ea23a0855e471c6612411":[4,0,5,0,1],
-"df/dcc/classDUID.html#adbe04141f4d8013a01effadda9c97c50acea738daca70f070501d426e76c87b73":[4,0,5,0,5],
-"df/dcc/classDUID.html#adbe04141f4d8013a01effadda9c97c50ad82e53106f45f3926b4142dc402c11e8":[4,0,5,0,0],
-"df/dcc/classDUID.html#adbe04141f4d8013a01effadda9c97c50ad8860466ab7048d3663a069e31170d4b":[4,0,5,0,2],
-"df/dcc/classDUID.html#adbe04141f4d8013a01effadda9c97c50af7f33513c9b6ac9ca4586439cd5c026d":[4,0,5,0,4],
-"df/dcc/classDUID.html#aebaa7a59dc9be131f1e9ede9bb0f1017":[4,0,5,3]
+"df/dc9/classisc_1_1dns_1_1DNSMessageFORMERR.html":[4,0,0,13,9]
 };
